@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -174,7 +174,7 @@ class CHost extends CHostGeneral {
 		if (!is_null($options['proxyids'])) {
 			zbx_value2array($options['proxyids']);
 
-			$sqlParts['where'][] = dbConditionInt('h.proxy_hostid', $options['proxyids']);
+			$sqlParts['where'][] = dbConditionId('h.proxy_hostid', $options['proxyids']);
 		}
 
 		// templateids
@@ -543,7 +543,6 @@ class CHost extends CHostGeneral {
 
 			if (array_key_exists('inventory', $host) && $host['inventory']) {
 				$hostInventory = $host['inventory'];
-				$hostInventory['hostid'] = $hostid;
 				$hostInventory['inventory_mode'] = HOST_INVENTORY_MANUAL;
 			}
 			else {
@@ -551,11 +550,13 @@ class CHost extends CHostGeneral {
 			}
 
 			if (array_key_exists('inventory_mode', $host) && $host['inventory_mode'] != HOST_INVENTORY_DISABLED) {
-				$hostInventory['hostid'] = $hostid;
 				$hostInventory['inventory_mode'] = $host['inventory_mode'];
 			}
 
-			if ($hostInventory) {
+			if (array_key_exists('inventory_mode', $hostInventory)
+					&& ($hostInventory['inventory_mode'] == HOST_INVENTORY_MANUAL
+						|| $hostInventory['inventory_mode'] == HOST_INVENTORY_AUTOMATIC)) {
+				$hostInventory['hostid'] = $hostid;
 				DB::insert('host_inventory', [$hostInventory], false);
 			}
 		}
@@ -655,16 +656,14 @@ class CHost extends CHostGeneral {
 		]);
 
 		foreach ($hosts as $host) {
-			// extend host inventory with the required data
-			if (isset($host['inventory']) && $host['inventory']) {
-				$inventory = $inventories[$host['hostid']];
-
-				// if no host inventory record exists in the DB, it's disabled
-				if (!isset($inventory['inventory_mode'])) {
-					$inventory['inventory_mode'] = HOST_INVENTORY_DISABLED;
+			// Extend host inventory with the required data.
+			if (array_key_exists('inventory', $host) && $host['inventory']) {
+				// If inventory mode is HOST_INVENTORY_DISABLED, database record is not created.
+				if (array_key_exists('inventory_mode', $inventories[$host['hostid']])
+						&& ($inventories[$host['hostid']]['inventory_mode'] == HOST_INVENTORY_MANUAL
+							|| $inventories[$host['hostid']]['inventory_mode'] == HOST_INVENTORY_AUTOMATIC)) {
+					$host['inventory'] = $inventories[$host['hostid']];
 				}
-
-				$host['inventory'] = $inventory;
 			}
 
 			$data = $host;
@@ -763,6 +762,17 @@ class CHost extends CHostGeneral {
 			}
 		}
 
+		// Check inventory mode value.
+		if (array_key_exists('inventory_mode', $data)) {
+			$valid_inventory_modes = [HOST_INVENTORY_DISABLED, HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC];
+			$inventory_mode = new CLimitedSetValidator([
+				'values' => $valid_inventory_modes,
+				'messageInvalid' => _s('Incorrect value for field "%1$s": %2$s.', 'inventory_mode',
+					_s('value must be one of %1$s', implode(', ', $valid_inventory_modes)))
+			]);
+			$this->checkValidator($data['inventory_mode'], $inventory_mode);
+		}
+
 		// Check connection fields only for massupdate action.
 		if (array_key_exists('tls_connect', $data) || array_key_exists('tls_accept', $data)
 				|| array_key_exists('tls_psk_identity', $data) || array_key_exists('tls_psk', $data)
@@ -797,6 +807,11 @@ class CHost extends CHostGeneral {
 			);
 		}
 
+		// Property 'auto_compress' is not supported for hosts.
+		if (array_key_exists('auto_compress', $data)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
+		}
+
 		/*
 		 * Update hosts properties
 		 */
@@ -1155,25 +1170,25 @@ class CHost extends CHostGeneral {
 		$this->validateDelete($hostIds, $nopermissions);
 
 		// delete the discovery rules first
-		$delRules = API::DiscoveryRule()->get([
-			'output' => ['itemid'],
+		$del_rules = API::DiscoveryRule()->get([
+			'output' => [],
 			'hostids' => $hostIds,
 			'nopermissions' => true,
 			'preservekeys' => true
 		]);
-		if ($delRules) {
-			API::DiscoveryRule()->delete(array_keys($delRules), true);
+		if ($del_rules) {
+			API::DiscoveryRule()->delete(array_keys($del_rules), true);
 		}
 
 		// delete the items
-		$delItems = API::Item()->get([
+		$del_items = API::Item()->get([
+			'output' => [],
 			'templateids' => $hostIds,
-			'output' => ['itemid'],
 			'nopermissions' => true,
 			'preservekeys' => true
 		]);
-		if ($delItems) {
-			API::Item()->delete(array_keys($delItems), true);
+		if ($del_items) {
+			CItemManager::delete(array_keys($del_items));
 		}
 
 		// delete web tests
@@ -1570,6 +1585,11 @@ class CHost extends CHostGeneral {
 				);
 			}
 
+			// Property 'auto_compress' is not supported for hosts.
+			if (array_key_exists('auto_compress', $host)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
+			}
+
 			// Validate "host" field.
 			if (!preg_match('/^'.ZBX_PREG_HOST_FORMAT.'$/', $host['host'])) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
@@ -1630,6 +1650,13 @@ class CHost extends CHostGeneral {
 
 		$inventory_fields = zbx_objectValues(getHostInventories(), 'db_field');
 
+		$valid_inventory_modes = [HOST_INVENTORY_DISABLED, HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC];
+		$inventory_mode = new CLimitedSetValidator([
+			'values' => $valid_inventory_modes,
+			'messageInvalid' => _s('Incorrect value for field "%1$s": %2$s.', 'inventory_mode',
+				_s('value must be one of %1$s', implode(', ', $valid_inventory_modes)))
+		]);
+
 		$status_validator = new CLimitedSetValidator([
 			'values' => [HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED],
 			'messageInvalid' => _('Incorrect status for host "%1$s".')
@@ -1647,6 +1674,11 @@ class CHost extends CHostGeneral {
 				$this->checkValidator($host['status'], $status_validator);
 			}
 
+			if (array_key_exists('inventory_mode', $host)) {
+				$inventory_mode->setObjectName($host['host']);
+				$this->checkValidator($host['inventory_mode'], $inventory_mode);
+			}
+
 			if (array_key_exists('inventory', $host) && $host['inventory']) {
 				if (array_key_exists('inventory_mode', $host) && $host['inventory_mode'] == HOST_INVENTORY_DISABLED) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot set inventory fields for disabled inventory.'));
@@ -1734,6 +1766,11 @@ class CHost extends CHostGeneral {
 				);
 			}
 
+			// Property 'auto_compress' is not supported for hosts.
+			if (array_key_exists('auto_compress', $host)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
+			}
+
 			// Validate host permissions.
 			if (!array_key_exists($host['hostid'], $db_hosts)) {
 				self::exception(ZBX_API_ERROR_PARAMETERS, _(
@@ -1753,6 +1790,13 @@ class CHost extends CHostGeneral {
 
 		$inventory_fields = zbx_objectValues(getHostInventories(), 'db_field');
 
+		$valid_inventory_modes = [HOST_INVENTORY_DISABLED, HOST_INVENTORY_MANUAL, HOST_INVENTORY_AUTOMATIC];
+		$inventory_mode = new CLimitedSetValidator([
+			'values' => $valid_inventory_modes,
+			'messageInvalid' => _s('Incorrect value for field "%1$s": %2$s.', 'inventory_mode',
+				_s('value must be one of %1$s', implode(', ', $valid_inventory_modes)))
+		]);
+
 		$status_validator = new CLimitedSetValidator([
 			'values' => [HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED],
 			'messageInvalid' => _('Incorrect status for host "%1$s".')
@@ -1774,6 +1818,11 @@ class CHost extends CHostGeneral {
 				$this->checkValidator($host['status'], $status_validator);
 			}
 
+			if (array_key_exists('inventory_mode', $host)) {
+				$inventory_mode->setObjectName($host_name);
+				$this->checkValidator($host['inventory_mode'], $inventory_mode);
+			}
+
 			if (array_key_exists('inventory', $host) && $host['inventory']) {
 				if (array_key_exists('inventory_mode', $host) && $host['inventory_mode'] == HOST_INVENTORY_DISABLED) {
 					self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot set inventory fields for disabled inventory.'));
